summaryrefslogtreecommitdiff
path: root/lisp/emacs-lisp/cl.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/emacs-lisp/cl.el')
-rw-r--r--lisp/emacs-lisp/cl.el8
1 files changed, 7 insertions, 1 deletions
diff --git a/lisp/emacs-lisp/cl.el b/lisp/emacs-lisp/cl.el
index f2ced20e59e..b098a467f9f 100644
--- a/lisp/emacs-lisp/cl.el
+++ b/lisp/emacs-lisp/cl.el
@@ -108,6 +108,10 @@ printer proceeds to the next function on the list.
This variable is not used at present, but it is defined in hopes that
a future Emacs interpreter will be able to use it.")
+(defvar cl-unload-hook '(cl-cannot-unload)
+ "Prevent unloading the feature `cl', since it does not work.")
+(defun cl-cannot-unload ()
+ (error "Cannot unload the feature `cl'"))
;;; Predicates.
@@ -579,9 +583,10 @@ Keywords supported: :test :test-not :key"
"Non-nil means don't make CL functions autoload.")
;;; Autoload the other portions of the package.
;; We want to replace the basic versions of dolist, dotimes below.
(fmakunbound 'dolist)
(fmakunbound 'dotimes)
+(fmakunbound 'declare)
(mapcar (function
(lambda (set)
(let ((file (if cl-fake-autoloads "<none>" (car set))))
@@ -695,4 +700,5 @@ Keywords supported: :test :test-not :key"
(run-hooks 'cl-load-hook)
+;;; arch-tag: 5f07fa74-f153-4524-9303-21f5be125851
;;; cl.el ends here
@@ -579,9 +583,10 @@ Keywords supported: :test :test-not :key"
"Non-nil means don't make CL functions autoload.")
;;; Autoload the other portions of the package.
-;; We want to replace the basic versions of dolist, dotimes below.
+;; We want to replace the basic versions of dolist, dotimes, declare below.
(fmakunbound 'dolist)
(fmakunbound 'dotimes)